@@ -2,7 +2,8 @@
 
 use strict;
 use FindBin;
-use lib "$FindBin::Bin/../../lib";
+use File::Spec;
+use lib File::Spec->catdir( $FindBin::Bin, '..', '..', 'lib' );
 
 use GraphViz::ISA;
 use Foorum;
