@@ -6,8 +6,9 @@ use FindBin;
 use Cwd qw/abs_path/;
 use YAML::XS qw/LoadFile/;
 use File::Path;
+use File::Spec;
 
-my $path = abs_path("$FindBin::RealBin/../..");
+my $path = abs_path( File::Spec->catdir( $FindBin::RealBin, '..', '..' ) );
 
 print "You are going to configure Sphinx for foorum.\n",
     "=" x 50,
@@ -18,7 +19,7 @@ unless ($module_installed) {
     print "Please cpan Sphinx::Search first!\n\n";
 }
 
-my $config = LoadFile("$path/foorum_local.yml");
+my $config = LoadFile( File::Spec->catfile( $path, 'foorum_local.yml' ) );
 my $dsn    = $config->{dsn};
 my $user   = $config->{dsn_user};
 my $pass   = $config->{dsn_pwd};
@@ -33,7 +34,8 @@ if ( $dsn =~ /port=(\d+)/ ) {
     $port = $1;
 }
 
-open( my $fh, '<', "$path/conf/examples/sphinx.conf" ) or die $!;
+open( my $fh, '<', File::Spec->catfile( $path, 'conf', 'examples', 'sphinx.conf' ) )
+    or die $!;
 local $/ = undef;
 my $content = <$fh>;
 close($fh);
@@ -44,15 +46,21 @@ $content =~ s/__PASS__/$pass/isg;
 $content =~ s/__PORT__/$port/isg;
 $content =~ s/__HOME__/$path/isg;
 
-open( my $fh2, '>', "$path/conf/sphinx.conf" ) or die $!;
+open( my $fh2, '>', File::Spec->catfile( $path, 'conf', 'sphinx.conf' ) ) or die $!;
 print $fh2 $content;
 close($fh2);
 
-unless ( -d "$path/log" ) {
-    mkpath( ["$path/log"], 0, 0777 );    ## no critic (ProhibitLeadingZeros)
+unless ( -d File::Spec->catdir( $path, 'log' ) ) {
+    mkpath(
+        [ File::Spec->catdir( $path, 'log' ) ],    ## no critic
+        0, 0777                                    ## no critic (ProhibitLeadingZeros)
+    );                                             ## no critic (ProhibitLeadingZeros)
 }
-unless ( -d "$path/data/sphinx" ) {
-    mkpath( ["$path/data/sphinx"], 0, 0777 );    ## no critic (ProhibitLeadingZeros)
+unless ( -d File::Spec->catdir( $path, 'data', 'sphinx' ) ) {
+    mkpath(
+        [ File::Spec->catdir( $path, 'data', 'sphinx' ) ],    ## no critic
+        0, 0777    ## no critic (ProhibitLeadingZeros)
+    );             ## no critic (ProhibitLeadingZeros)
 }
 
 print "Configure is saved: $path/conf/sphinx.conf\n",
